Opinions & Announcements Search
Description: Opinion Site
Keywords: Decisions, Opinions, Files, Documents, Reporter

# The Supreme Court of Ohio & The Ohio Judicial System

## Opinions & Announcements
Source: |
Decided: |
WebCite No: |
Full Text: |
Enter either a webcite number or a full text query.
Columns to Include
Case Name Case No Topics/Issues | Author County Citation | Decided Date Posted Date WebCite
Notices
Supreme Court opinions and Supreme Court announcements are usually posted weekdays at 9:00 a.m. Other documents are posted as received by the court.
All documents are in the Adobe® PDF format. The Adobe® Reader® is a free download. |
| Rows per Page

328 documents were found matching the selected criteria.
Page: [ 1] 2 3 4 next

Case Name | Case No. | Topics and Issues | Author | Decided | WebCite
--- | --- | --- | --- | --- | ---
State v. Weese | 2013-CA-61 | The appellate record of convictions resulting from agreed-upon pleas and sentences reveals no non-frivolous issues for review. Judgment affirmed. | Hall | 7/25/2014 | 2014-Ohio-3267
State v. Ward | 25868 | Appellate counsel filed an Anders brief concluding that there are no meritorious issues to present on appeal. Neither the Appellant nor his counsel raised any potential assignments of error having arguable merit for review. After conducting an independent review of the proceedings, we agree that there are no issues with arguable merit for appeal. Affirmed. | Welbaum | 7/25/2014 | 2014-Ohio-3266
State v. Rowe | 25993 | Defendant’s convictions on two counts of aggravated menacing were supported by sufficient evidence and were not against the manifest weight of the evidence, despite the reliance by the State on the testimony of two children, who were the victims of the alleged offenses. (The defense also relied on child witnesses.) In a bench trial, we presume that the trial court disregarded any improper hearsay evidence. Judgment affirmed. | Froelich | 7/25/2014 | 2014-Ohio-3265
PNC Bank, N.A. v. Creative Cabinet Sys., Inc. | 2013-CA-14, 2013-CA-15 | Appellant appeals from a trial court order giving escrowed funds temporarily to the Clerk of Courts. This order is not final under R.C. 2505.02, so jurisdiction to consider this appeal’s merits is lacking. Appeal dismissed. | Hall | 7/25/2014 | 2014-Ohio-3264
Whitaker v. Paru Selvam, L.L.C. | 26103, 26108 | The trial court did not err in concluding that corporate defendants who were accused of fraudulent transfers were properly served with the complaint. The corporate defendants also received an opportunity to show in writing why default judgment should not be entered. They, therefore, received all process that they were due under Civ.R. 55(A). Furthermore, assuming for purposes of argument that a procedural irregularity occurred, the defendants waived any error by failing to object in the trial court. The trial court also complied with Civ.R.55(C), because the default judgment awarded the same relief that had been requested in the complaint. In addition, the trial court did not abuse its discretion by failing to allow the filing of an intervening defendant’s proposed amended answer and counterclaim. Justice did not require the filing of the answer and counterclaim. Finally, the trial court did not err in failing to consider the application of res judicata, as the matter was not properly raised and was not before the court. Affirmed. | Welbaum | 7/25/2014 | 2014-Ohio-3263
McCarty v. Pedraza | 2013-CA-42 | The trial court did not err by entering partial summary judgment on the issue of negligence and by awarding damages for attorney fees to mitigate damages, and for the loss of a counterclaim, in Appellees’ claim for legal malpractice. But the trial court did err by also awarding Appellees an amount equal to the amount of the underlying default judgment entered against them as a result of the malpractice where Appellees failed to present sufficient evidence that no judgment, or only a judgment of a lesser amount, would have been entered against them had the attorney timely filed an answer on their behalf. Judgment affirmed in part and reversed in part; remanded. (Froelich, P.J., dissenting in part and concurring in part.) | Hall | 7/25/2014 | 2014-Ohio-3262
LaSalle Bank Natl. Assn. v. Brown | 25822 | The trial court did not err in overruling a motion to vacate filed by the purchaser at a foreclosure sale, after confirmation of the sale. The purchaser lacked standing to appeal the decision of the trial court because she failed to file a motion to intervene pursuant to Civ.R. 24(C). Furthermore, the purchaser could not collaterally attack the foreclosure judgment as a nonparty, because the bank that originally filed the foreclosure action had standing to sue. The bank was the owner of the note and mortgage, and was entitled to enforce the note as a nonholder in possession of the instrument. Even if the purchaser has standing to appeal, her claim is barred by caveat emptor, as any defects in title or in the court proceedings were of public record and could have been discovered prior to the judicial sale. Finally, assuming for purposes of argument that the bank lacked standing when the foreclosure action was initially filed, the judgment would be only voidable, not void. However, the purchaser failed to file a motion to intervene and also failed to file a motion to set the judgment aside under Civ.R. 60(B). Affirmed. (Donovan, J., dissenting). | Welbaum | 7/25/2014 | 2014-Ohio-3261
Village of St. Paris v. Galluzzo | 2014-CA-4 | In appeal from conviction and sentence for violation of a municipal ordinance prohibiting driving with an expired vehicle registration, the defendant’s assignments of error are without merit. The trial court had both subject-matter and personal jurisdiction. The trial court did not err in striking the defendant’s demurrer, which is not a pleading recognized in Ohio. The ordinance does not infringe upon the defendant’s constitutional right to travel. The defendant’s motor vehicle is not exempt from registration requirements as a “consumer good,” under the Uniform Commercial Code. The ordinance is not a “bill of pains and penalties” prohibited by the Eighth Amendment to the United States Constitution. The trial court did not improperly deny the defendant access to its rulings. Neither did the trial court improperly deny the defendant’s request for findings of fact and conclusions of law pursuant to Civ.R. 52. Affirmed. | Fain | 7/25/2014 | 2014-Ohio-3260
State v. Eberhart | 26045, 26046 | The trial court did not err in rejecting the appellant’s argument that it lacked personal jurisdiction over him. Personal service of two traffic citations and summonses for misdemeanor offenses gave the Miamisburg Municipal Court personal jurisdiction over the appellant. Judgment affirmed. | Hall | 7/25/2014 | 2014-Ohio-3259
Corey v. Corey | 2013-CA-73 | (1) The trial court did not err by relying on the guardian ad litem’s written report. The report was admitted into evidence without objection. Appellant may not object for the first time on appeal, and there is no plain error. (2) The trial court did not err by changing the children’s sole residential parent from Appellant to Appellee. Given the evidence presented, the court’s findings under R.C. 3109.04(D)(1)(a) are reasonable. Judgment affirmed. | Hall | 7/25/2014 | 2014-Ohio-3258
State v. Brown | 26035 | Trial court did not err when it overruled appellant’s motion to suppress because even though he was under arrest, his statements were admissible under the “public safety exception” to the Miranda rule. The questions posed to appellant by the deputy without the benefit of Miranda warnings were objectively reasonable given the immediate danger presented by a potentially loaded handgun which may have been discarded in the area surrounding an apartment complex where many adults and children were present. Judgment affirmed. | Donovan | 7/25/2014 | 2014-Ohio-3257
State v. Williams | 2013 CA 74 | Trial court did not err in denying defendant’s motion for relief from a default judgment, pursuant to Civ.R. 60(B). Trial court did not abuse its discretion in concluding that defendant did not demonstrate that his failure to respond to the complaint was due to “excusable neglect” under Civ.R. 60(B)(1) or fraud by the plaintiff under Civ.R. 60(B)(3). Judgment affirmed. | Froelich | 7/18/2014 | 2014-Ohio-3169
State v. Rothermel | 26004 | The trial court’s decision finding that Appellant was not acting in self-defense when he committed assault was not against the manifest weight of the evidence. The record indicated that Appellant did not have a bona fide belief that he was in imminent danger of death or great bodily harm and that the only means of escape from such danger was to use deadly force. Additionally, Appellant used more force than reasonably necessary. Affirmed. | Welbaum | 7/18/2014 | 2014-Ohio-3168
Jackson v. Force | 2014 CA 6 | Prospective buyers of farm brought suit against seller of farm after seller indicated that she had received a better offer and repudiated the agreement. Trial court did not err in granting summary judgment to seller on the prospective buyers’ claims for fraud/ misrepresentation and specific performance. Although the trial court erred in finding that there was no mutual assent and that mutual mistake rendered the contract void, specific performance was nevertheless unavailable where seller signed the agreement as an attorney-in-fact, the principal’s interest was limited to a life estate, and the principal had died, extinguishing the life estate interest. Regardless of whether prospective buyers were justified in relying on seller’s representation that she had authority to sell the entire farm, summary judgment on the fraud/ misrepresentation claim was proper where there was no evidence that seller intended to mislead the buyers at the time the agreement was signed. Trial court properly dismissed claim against real estate agent for tortious interference with contract claim where no enforceable contract existed when agent contacted seller. Judgment affirmed. | Froelich | 7/18/2014 | 2014-Ohio-3167
State v. Herron | 25850 | The trial court did not err in overruling Appellant’s motion to suppress evidence, since a substantial crack in the windshield of the vehicle in which Appellant was a passenger supported a reasonable, articulable suspicion that the vehicle was in an unsafe condition, and since, under the totality of the circumstances, the driver of the vehicle voluntarily consented to a search of the vehicle (which produced a weapon) in the course of the lawful stop. Judgment affirmed. | Donovan | 7/18/2014 | 2014-Ohio-3166
State v. Cook | 2013 CA 22 | On appeal, defendant challenged for the first time trial judge’s presiding over defendant’s community control revocation hearing when the judge had personally participated in a prior revocation hearing while the county prosecutor. Defendant waived his challenge to the trial judge’s participation in the second revocation hearing by failing to seek recusal or disqualification prior to the hearing. Defendant did not establish that his trial counsel was ineffective for failing to seek recusal of the trial judge, to request a competency hearing or to enter a not guilty by reason of insanity plea. Judgment affirmed. | Froelich | 7/18/2014 | 2014-Ohio-3165
State v. Burrows | 25918 | In prosecution for Having a Weapon While Under a Disability, the trial court did not err in overruling an objection to the admission of defendant’s confession that he had fired a shotgun outside his house. The presence of spent shotgun shells outside his house and a stipulation that the defendant was under a disability constituted sufficient evidence of the fact that the crime was committed, and that the defendant committed it, to satisfy the corpus delicti rule. The evidence in the record was sufficient to sustain the defendant’s conviction. The jury’s finding that the defendant had failed to prove, by a preponderance of the evidence, the affirmative defense of self-defense, is not against the manifest weight of the evidence. Affirmed. (Hall, J., concurring). | Fain | 7/18/2014 | 2014-Ohio-3164
State v. Baker | 25828 | Defendant’s convictions for murder, aggravated robbery, and felonious assault were supported by the evidence and were not against the manifest weight of the evidence. Defendant was not denied the effective assistance of counsel. Judgment affirmed. | Froelich | 7/18/2014 | 2014-Ohio-3163
Haggerty v. Upchurch | 25912 | The trial court’s judgment dismissing Appellee’s will-contest action under Civ.R. 3 and 4 is not only correct, but required. The action was never commenced. Therefore whether the court also correctly concluded that the statute of limitations in R.C. 2107.76 does not bar the action is a moot issue. Judgment affirmed. | Hall | 7/18/2014 | 2014-Ohio-3162
In re S.A. | 25994, 26001 | The trial court did not err in awarding permanent custody of the parties’ children to Montgomery County Children’s Services. There is sufficient evidence in the record to support the trial court’s findings that the children either cannot be, or should not be, placed with either parent within a reasonable time, and that it is in the best interests of the children that their permanent custody be awarded to the agency. Mother’s trial counsel was not ineffective for having failed to object to the admission of evidence of an improper relationship between Mother and her father. The trial court could have found that the probative value of this evidence outweighed any unfair prejudice its admission would cause; therefore, if trial counsel had objected, the objection would likely have been overruled. Affirmed. | Fain | 7/11/2014 | 2014-Ohio-3063
State v. Maxwell | 2013-CA-63 | Trial court erred in overruling motion to suppress evidence obtained as the result of a traffic stop. Police officer’s testimony that: (1) defendant, when making a signaled lane change from the left lane to the right lane, straddled the line dividing the two lanes for 50 to 100 feet, while traveling at 45 miles per hour; (2) defendant then left his right-turn signal on for an additional 300 yards before exiting the highway to the right; and (3) defendant exited the highway at a point where there was no access to the Wright Patterson Air Force Base, neither establishes probable cause to believe that a traffic violation was committed, nor reasonable and articulable suspicion of impaired driving. Therefore, the stop was unlawful, and the evidence obtained as a result of the stop should have been suppressed. Defendant’s OMVI conviction Reversed, and cause Remanded. (Welbaum, J., dissenting.) | Fain | 7/11/2014 | 2014-Ohio-3062
In re M.W. | 26107 | The record supports the trial court’s finding that awarding Montgomery County Children Services permanent custody was in the best interest of the appellant’s two children. Judgment affirmed. | Hall | 7/11/2014 | 2014-Ohio-3061
In re M.O. | 25965 | In response to a motion from children services for legal custody, the trial court erred in granting a third extension of temporary custody, which continued temporary custody for a period exceeding two years. R.C. 2151.353(F) and R.C. 2151.415(D) preclude a third extension of temporary custody and a total period of temporary custody exceeding two years. See also In re D.J., 2d Dist. Montgomery No. 21666, 2006-Ohio-6304. Judgment reversed and remanded. | Froelich | 7/11/2014 | 2014-Ohio-3060
State v. Louden | 2013 CA 30, 2013 CA 31 | Appellant forfeited any claim of bias and prejudice when he elected to proceed with his second revocation hearing before the trial judge without filing an affidavit of disqualification in the Supreme Court of Ohio. Record fails to demonstrate that trial counsel was ineffective for having failed to file an affidavit of disqualification. The trial court erred in ordering appellant to pay his court-appointed legal fees as costs of the case. Reimbursement for such costs is available to the county only through a civil action. State v. Miller, 2d Dist. Clark No. 08CA0090, 2010-Ohio-4760, ¶ 61; R.C. 2941.51(D). The portion of the court’s judgment imposing legal fees as costs is vacated; in all other respects, the judgment is affirmed. | Donovan | 7/11/2014 | 2014-Ohio-3059
State v. Kesting | 25789 | Defendant’s conviction for domestic violence was not against the manifest weight of the evidence. The trial court did not improperly reserve its ruling on defendant’s Crim.R. 29(A) motion at the end of the State’s case; the court overruled the motion, even though the court stated that it would consider further argument at a later time. The trial court’s remarks to the witness while instructing her to answer questions directly were not prejudicial. No ineffective assistance of counsel was demonstrated. Judgment affirmed. (Donovan, J., concurring). | Froelich | 7/11/2014 | 2014-Ohio-3058
State v. Jemison | 25967 | The appellant waived any objection to the transfer of his community control revocation case from one judge to another by failing to object. The record fails to support the appellant’s argument that the trial court engaged in improper ex parte communication with another judge or with Ohio Supreme Court personnel. The trial court did not abuse its discretion in revoking the appellant’s community control based on his failure to make any real effort to obtain a job or a GED for roughly seven months. Judgment affirmed. | Hall | 7/11/2014 | 2014-Ohio-3057
State v. Drager | 26067 | The trial court did not err in finding that Appellant had two prior OVI convictions within six years of his current OVI offense and enhancing his sentence pursuant to R.C. 4511.19(G)(1)(c). Because Appellant was represented by counsel during his prior convictions, he is now prohibited from collaterally attacking the validity of those convictions in the present case. Affirmed. | Welbaum | 7/11/2014 | 2014-Ohio-3056
Gibbs v. Speedway, L.L.C. | 26026 | The trial court did not err in rendering summary judgment against the plaintiff in a slip and fall case. The plaintiff could not identify the cause of his fall. Assuming that his fall was due to ice, the snow and ice were the result of natural accumulations. Further assuming that the lighting was insufficient, the danger was open and obvious. Finally, the defendant is not liable under a theory of negligence per se, because an applicable municipal ordinance pertaining to lighting of spaces is not a specific rule that establishes a standard of conduct replacing the “reasonable person” standard. Affirmed. | Welbaum | 7/11/2014 | 2014-Ohio-3055
State v. Scerba | 2013 CA 96 | The defendant entered a guilty plea, withdrew it, and then entered a second, more favorable plea agreement with the State. The record refutes defendant’s claims that his second guilty plea, on which he was convicted, was entered involuntarily and that he was denied the effective assistance of counsel. Judgment affirmed. | Froelich | 7/3/2014 | 2014-Ohio-3002
Ransdell v. Ransdell | 25831 | The trial court lacked jurisdiction to modify Appellant’s lump sum spousal support obligation. Judgment reversed and vacated. | Donovan | 7/3/2014 | 2014-Ohio-3001
State v. Patton | 2013-CA-41 | The trial court did not abuse its discretion in denying the appellant’s post-sentence motion for the return of property where the State made an unchallenged representation that the property had potential evidentiary value in a Colorado criminal case against the defendant. Judgment affirmed. | Hall | 7/3/2014 | 2014-Ohio-3000
State v. Minnich | 2013 CA 40 | The trial court did not err when it accepted appellant’s no contest plea because the record establishes that the plea was entered into in a knowing, intelligent, and voluntary fashion. The trial court’s imposition of a thirty-month prison sentence was neither contrary to law nor an abuse of discretion. Judgment affirmed. | Donovan | 7/3/2014 | 2014-Ohio-2999
Johnson v. Wal-Mart Stores E., L.P. | 25972 | Trial court did not err in rendering summary judgment for store owner in suit by customer injured when she and another customer on one of the store’s motorized shopping carts either collided, or nearly collided, just past a shopping display. The store owner established that it did not breach any duty of care the breach of which was alleged to have caused the plaintiff’s injury. The danger of a collision between a pedestrian customer and a customer using a motorized cart is sufficiently obvious that the owner of the store had no duty to warn either customer of that danger. There was neither any allegation in the complaint, nor any evidence offered by either party, that the motorized cart was not operated properly, or malfunctioned in any way. The store owner had no duty not to erect displays above eye-level in its store-long, fifteen-foot wide aisles. Affirmed. | Fain | 7/3/2014 | 2014-Ohio-2998
State v. Erdman | 25814 | No non-frivolous issues for appellate review. The appellant is challenging the trial court’s revocation of community control, but he has completed the sentence imposed upon revocation. Appeal dismissed as moot. | Hall | 7/3/2014 | 2014-Ohio-2997
BD Dev. v. Vandalia | 25930 | The trial court did not err in allowing the introduction of additional evidence in an administrative appeal, pursuant to R.C. 2506.03, since the testimony before the City Council was not given under oath. The City’s decision was not supported by substantial, reliable, probative evidence. The trial court, which had extensive authority to weigh the evidence adduced at the hearing, did not abuse its discretion in concluding that Appellee complied with the zoning regulation at issue and that a variance was not required. Judgment affirmed. | Donovan | 7/3/2014 | 2014-Ohio-2996
Cartwright v. Batner | 25938 | The trial court did not abuse its discretion in determining that an accounting for a revocable trust was adequate for periods between June 2007 and 2009. However, the court did err in concluding that a claim regarding misuse of a power of attorney before June 2007 belonged to the estate, and that the remedy was in probate court. Appellant was entitled to bring an action in common pleas court, which had concurrent jurisdiction over the matter. The court also erred in concluding, on the merits of this claim, that Appellant failed to prove a misuse of powers of attorney granted to Appellee. There was sufficient evidence of transfers to Appellee, causing the burden to shift to Appellee to show that his conduct was free of undue influence and fraud. Appellee failed to present such evidence. Additionally, Appellee violated prohibitions against self dealing with respect to a condominium that was part of the irrevocable trust, and should be required to reimburse the trust for the fair market rental value of the condominium from the time that he began living there. The trial court further erred in dismissing Appellant’s claim for civil damages under R.C. 2307.60 and R.C. 2307.61. Because of the error regarding Appellee’s alleged misuse of the power of attorney and Appellant’s entitlement to bring a civil action under R.C. 2307.60 and R.C. 2307.61, the attorney fee awards must be reversed. Affirmed in part, Reversed in part, and remanded for further proceedings. | Welbaum | 7/3/2014 | 2014-Ohio-2995
Auer v. Paliath | 25888 | Appellee has a meritorious defense to present, and the trial court did not abuse its discretion in granting Appellee’s timely motion for relief from judgment on the basis of “mistake, inadvertence, surprise or excusable neglect.” Judgment affirmed. | Donovan | 7/3/2014 | 2014-Ohio-2994
Tye v. Upper Valley Med. Ctr. | 25997 | The judgment of the trial court that postsettlement interest accrued as of November 8, 2012, and not on the settlement date of July 21, 2012, is error; the Tyes are entitled to postsettlment interest on the cash portion of their settlement from the settlement date as of July 21, 2012. The trial court’s October 22, 2013 decision is modified to reflect that postsettlement interest on the cash portion began to run on July 21, 2012. Judgment modified, and as modified, affirmed. | Donovan | 6/27/2014 | 2014-Ohio-2822
State v. Taylor | 2013-CA-59 | The State concedes, and we determine that the trial court erred in finding the defendant statutorily ineligible for intervention in lieu of conviction under the S.B. 160 version of the ILC statute. Judgment reversed and cause remanded. | Hall | 6/27/2014 | 2014-Ohio-2821
State v. Peck | 25999 | Trial court did not err in overruling motion to suppress evidence obtained as the result of a warrantless entry into the defendant’s hotel room. Another person in the hotel had told the police that the defendant had waved a gun at him. Two others corroborated this report. When the police officers knocked and identified themselves as police officers, a woman opened the door partially. The officers saw the defendant dive towards the floor. The report of the defendant’s menacing use of a gun, combined with his sudden diving motion upon seeing the police at the door, gave the police both probable cause and exigent circumstances for the warrantless entry, based upon legitimate concern for their own safety and the safety of the other occupant or occupants in the room. Affirmed. | Fain | 6/27/2014 | 2014-Ohio-2820
State v. McCain | 26020 | The trial court did not err in overruling Appellant’s petitions for postconviction relief given that the petitions were untimely filed and the claims asserted therein were barred by res judicata. Affirmed. | Welbaum | 6/27/2014 | 2014-Ohio-2819
Bank of Am., N.A. v. Longberry | 2014-CA-9 | The trial court did not err in granting summary judgment in favor of Appellee on its foreclosure action. Appellee presented sufficient evidentiary materials entitling it to summary judgment, and Appellants failed to file a response establishing the existence of a genuine issue of material fact for trial. Affirmed. | Welbaum | 6/27/2014 | 2014-Ohio-2818
Bell v. Kinman | 2014-CA-2 | Trial court did not err when it entered an agreed order modifying child support and parenting time. The trial court had the jurisdiction to enter the order. The record reflects that the terms of the order were the subject of an in-court agreement between the parties, and the record does not support the appellant’s contention that her agreement was the product of duress. Affirmed. | Fain | 6/27/2014 | 2014-Ohio-2817
State v. Kendrick | 26042 | The trial court did not err in denying the appellant’s motion for a finding under R.C. 149.43(B)(8) to support a public-records request. That statute requires an inmate seeking records related to a criminal investigation or prosecution to support his public-records request with a finding by the sentencing judge that the information sought is necessary to support what appears to be a justiciable claim. The appellant undisputably had no justiciable claim where no proceedings were pending, he pled guilty to multiple counts of rape years ago, and his convictions long since had become final. Judgment affirmed. | Hall | 6/27/2014 | 2014-Ohio-2816
State v. Johnson | 25773 | The phrase “ready at hand” as used in R.C. 2923.12 is not unconstitutionally void for vagueness. Thus, the trial court did not err when it relied on that portion of the statute in order to find appellant guilty of carrying a concealed weapon. R.C. 2923.12 does not violate appellant’s Second Amendment right to bear arms. R.C. 2923.16 and R.C. 2923.12 do not conflict in such a manner that appellant could not conform his conduct to one statute without violating the other. Trial court did not err when it overruled appellant’s motion to suppress because a stop or arrest in violation of the territorial limits imposed by statute upon a police officer’s arrest powers is not a constitutional violation, and will not, therefore, support the extraordinary remedy of exclusion of evidence obtained as a result of an unlawful stop or arrest. Judgment affirmed. | Donovan | 6/27/2014 | 2014-Ohio-2815
In re J.W. | 2013-CA-113, 2013-CA-114 | The trial court did not err in awarding permanent custody to the children services agency. The court carefully considered all appropriate factors, and its decision is supported by clear and convincing evidence in the record. The trial court also did not err in failing to appoint counsel for the minor children. Counsel need only be appointed in certain circumstances, and is not required where, as here, references to a desire to reunify were a child's only occasional expression of a wish to be with a parent. In addition, the trial court did not unconstitutionally penalize the parents for their poverty. Instead, the parents chose to spend their money staying in hotels rather than obtaining housing for the children, and additionally failed to comply with even the most minimal requirements of their case plan. Finally, the trial court based its findings on R.C. 2151.414(B)(1)(a), not on R.C. 2151.414(B)(1)(d), as Appellant contends, and there is no need to consider arguments as to jurisdiction under the latter subsection of the statute. Affirmed. (Fain, J., dissenting.) | Welbaum | 6/27/2014 | 2014-Ohio-2814
In re J.O. | 25903 | Juvenile court’s decision finding appellant delinquent for committing rape was not against the manifest weight of the evidence. Pursuant to the plain language in R.C. 2152.82, the juvenile court was required to classify appellant as a Tier III juvenile sex offender at the time of his disposition because it was his second sex offense as a juvenile. Appellant did not receive ineffective assistance when his counsel failed to object to the juvenile court’s classification of appellant as a Tier III juvenile sex offender registrant at the dispositional hearing. Judgment affirmed. | Donovan | 6/27/2014 | 2014-Ohio-2813
State v. Farmer | 25956 | The trial court did not abuse its discretion in denying the appellant’s motion for leave to file a delayed motion for a new trial. The record supports the trial court’s finding that the appellant could have filed a new-trial motion within the 120 days allowed by Crim.R. 33(B). Even accepting the appellant’s claim that he reasonably could not have complied with the 120-day time requirement, he failed to show that he filed his motion for leave within a reasonable time after discovering the evidence at issue. Judgment affirmed. | Hall | 6/27/2014 | 2014-Ohio-2812
Certain Underwriters at Lloyds v. Woodling | 2013-CA-7 | Insurance company entered into automobile insurance contract in Michigan, with a Michigan resident. The insured was injured in an automobile accident in Ohio, and insurance company paid its insured certain benefits under the policy. Insurance company then sought to recover in Ohio against the tortfeasor, as subrogee of its insured. Under Michigan law, an insurance company may not recover benefits directly against a tortfeasor, as subrogee. Michigan law governed this issue, which arises from the contract between the insurance company and its insured, which contract was entered into in Michigan with a Michigan resident. Therefore, trial court did not err in rendering summary judgment in favor of the defendant tortfeasor. Affirmed. | Fain | 6/27/2014 | 2014-Ohio-2811
Anguiano v. Ohio Dept. of Edn. | 2014-CA-2 | The trial court reversed the Department of Education decision when the trial court determined that the Appellant had not considered Appellee’s rehabilitation in its decision to deny Appellee’s application for a pupil activity permit. The trial court erred because Appellee has been convicted of a felony and an offense of violence, and he cannot, as a matter of law, satisfy the rehabilitation criteria in former Ohio Adm.Code 3301 20 01. Judgment reversed. | Hall | 6/27/2014 | 2014-Ohio-2810
State v. Tyner | 25405 | The trial court did not err in overruling the appellant’s motion to suppress field-sobriety test results and blood-alcohol test results where the record reveals substantial compliance with applicable administrative regulations. The State concedes, and we find, that the trial court erred in imposing partially consecutive sentences without making the findings required by R.C. 2929.14(C)(4). Judgment affirmed in part, reversed in part, and cause remanded for resentencing. | Hall | 6/27/2014 | 2014-Ohio-2809
Sacksteder v. Senney | 25892 | Appellant is plaintiff in an ongoing legal malpractice action against defendants. Appellant filed this separate action for replevin, conversion, and breach of fiduciary duty in order to obtain the “original” of the case file maintained by his former attorneys. The attorneys provided copies of the files, at their cost, and an opportunity for appellant and his new lawyer to physically inspect the “original.” The trial court did not err by entering summary judgment for Appellees on Appellants’ claims. Except for original documents or materials provided to an attorney by the client, which are the client’s property, the client does not own or have the immediate right to possess the original papers or documents produced by the attorney in Appellants’ case files. Judgment affirmed. | Hall | 6/20/2014 | 2014-Ohio-2678
State v. Ratliff | 2013-CA-24 | Anders brief filed. Defendant pled guilty to Possession of Heroin and Tampering with Evidence. A third count, Trafficking in Heroin, was dismissed. Defendant was sentenced to 24 months imprisonment for Possession of Heroin, and to 12 months imprisonment for Tampering with Evidence, to be served concurrently with one another, but consecutively with a separate sentence imposed in proceedings in Union County. The trial court made the findings required by statute for the imposition of consecutive sentences. The record reflects that when he tendered his plea, the defendant was correctly advised of the possibility that his sentences in this case could be ordered to be served consecutively to any sentence imposed in the Union County case. The record reflects that the trial court complied with the requirements of Crim.R. 11 when it accepted the defendant’s plea. Independent review of the record reveals no potential assignments of error having arguable merit. Affirmed. | Fain | 6/20/2014 | 2014-Ohio-2677
State v. Kay | 25761 | Defendant’s conviction for Murder is supported by sufficient evidence, and is not against the manifest weight of the evidence. The trial court did not commit plain error when it failed to merge defendant’s Aggravated Burglary and Aggravated Robbery convictions. Evidence in record did not establish that the defendant did not separately commit the offenses. As the State concedes, the trial court did err in imposing consecutive sentences without making the findings required by R.C. 2929.14(C)(4). That part of the judgment imposing consecutive sentences is Reversed; the judgment is Affirmed in all other respects; and the cause is Remanded for further proceedings with respect to the issue of whether to impose the sentences consecutively or concurrently. | Fain | 6/20/2014 | 2014-Ohio-2676
State v. Haynes | 2013 CA 90 | Issues raised in defendant’s brief are barred by res judicata, because he could have raised them on direct appeal and did not do so; we will not consider these issues. Several of the issues were also raised in a motion for delayed appeal, which we overruled. Judgment affirmed. | Froelich | 6/20/2014 | 2014-Ohio-2675
In re H.Y. | 26082 | The trial court did not abuse its discretion in overruling Appellant’s motion for new trial, based on the removal of the magistrate who heard the custody case. Civ.R. 63(B), relied on by Appellant, does not apply to magistrates, and the trial court properly conducted an independent review of the record, as is required by Juv.R. 40(D)(4)(d). The court also did not abuse its discretion in awarding custody of the child to the father. R.C. 3109.042 provides only a statutory designation of legal and residential custody to unmarried females. However, when a court makes an initial custody decision, the parents stand on equal footing. Furthermore, Appellant was not the primary caretaker; both parents spent equal amounts of time caring for the child. Appellant also had some mental health issues that the court was entitled to consider. Affirmed. | Welbaum | 6/20/2014 | 2014-Ohio-2674
State v. Fannon | 25957 | The trial court did not err in overruling the Appellant’s post-sentence motion to withdraw his guilty plea, as the claims in the motion are barred by the doctrine of res judicata. In addition, the motion was untimely and failed to establish manifest injustice. Affirmed. | Welbaum | 6/20/2014 | 2014-Ohio-2673
State v. Christian | 25256 | The affidavit in support of the search warrant for Defendant’s home provided a reasonable basis for the issuance of the warrant; Defendant’s motion to suppress was properly overruled. There was insufficient evidence from which the jury could have concluded that Defendant engaged in a pattern of corrupt activity. Accordingly, that conviction will be reversed, as will the trial court’s order that Defendant forfeit her home based on her conviction for engaging in a pattern of corrupt activity; further, a forfeiture specification was not in the indictment. The amount of a fraudulent insurance claim and the economic harm caused by making false alarm determine the degree of the respective offenses, but do not constitute elements of the offenses to which the mens rea applies. H.B. 86, which went into effect while this case was pending, changed the threshold amounts of a fraudulent insurance claim and of “economic harm” which constitute the various degrees of insurance fraud and making false alarm, respectively. The trial court properly sentenced Defendant in accordance with H.B. 86, but it erred in failing to also convict her of the (lower) degrees of the offenses provided by H.B. 86. An insurance company can be entitled to restitution as the victim of an offense (insurance fraud), despite the fact that it cannot be paid restitution as a third-party who had reimbursed a victim; costs of investigating insurance fraud can constitute economic harm forming a basis for an order of restitution to the insurance company, even if the investigation resulted in the denial of the claim. The trial court erred in permitting the sheriff’s department to include the entire cost of its investigation into burglary and insurance fraud as “economic loss” resulting from the offense of making false alarm. Applying the new threshold amounts set forth in H.B. 86, and including only those costs directly associated with making false alarm, Defendant should have been convicted of lesser degrees of insurance fraud (Count Two) and making false alarm (Count Three). Law enforcement agencies and fire departments are not “victims” entitled to restitution for the cost of the services they render. Defendant responded to a question at trial by stating that another witness (her former employee) had been convicted of attempted manslaughter in the past. The trial court did not abuse its discretion in striking Defendant’s answer, which was not responsive to the question she had been asked, or in clarifying to the jury that the witness-employee had not, in fact, ever been convicted of that offense. The trial court also did not abuse its discretion in calling a man whom Defendant had allegedly paid to commit burglary and vandalism as a court’s witness; the witness had an interest in protecting Defendant and had not shown any willingness to cooperate with the State. Defendant’s impeachment through her prior inconsistent conduct was not improper, and the recorded conversation by which she was impeached was properly authenticated. Judgment affirmed in part, reversed in part, and remanded. Defendant’s conviction for engaging in a pattern of corrupt activity will be reversed, as will the forfeiture of her house ordered in connection with that conviction. Defendant’s convictions for insurance fraud (Count Two) and making false alarm (Count Three) will be modified to reflect lower degrees of the offenses; as modified, these convictions will be affirmed. The awards of restitution to the insurance companies will be affirmed, and the awards of restitution to the sheriff’s department and fire department will be reversed. The matter is remanded for resentencing on Counts Two and Three, and for entry of a judgment consistent with this opinion. (Hall, J., concurring and dissenting.) | Froelich | 6/20/2014 | 2014-Ohio-2672
State v. Chaffin | 25220 | The trial court did not err in overruling Appellant’s motion to suppress evidence of his pre-trial identification on remand. Likewise the trial court did not err in holding a supplementary evidentiary hearing on the suppression issue. In addition, it was not an abuse of discretion for the trial court to poll the jurors in order to determine whether juror number four’s verdicts were made voluntarily. The trial court also did not err in refusing to grant a mistrial based on an alleged Bruton violation, because no such violation occurred. Appellant’s trial counsel was not ineffective in failing to move for a separate trial given that Appellant was not prejudiced by having his case tried jointly with his co-defendant. The State concedes that the trial court erroneously imposed court costs and prematurely disapproved of transitional control in the court’s termination entry. The remaining assignments of error were not raised in Appellant’s original appeal and are barred by the doctrine of res judicata. Affirmed in part, reversed in part, and remanded for the limited purposes of permitting Appellant to request a waiver of court costs and for the trial court to revise the language in the termination entry. | Welbaum | 6/20/2014 | 2014-Ohio-2671
State v. Cain | 2013-CA-31 | The trial court did not err in denying the appellant’s delayed post-sentence motion to withdraw his guilty pleas where (1) the motion offered no support for his claim that the parties mistakenly had believed his actions constituted rape and gross sexual imposition and (2) he did not cite anything to support his claim of actual innocence. The appellant cannot challenge the trial court’s denial of a suppression motion in the context of an appeal from the denial of post-sentence plea-withdrawal motion. Judgment affirmed. | Hall | 6/20/2014 | 2014-Ohio-2670
State v. Butler | 2013-CA-110 | The trial court did not err in ordering Appellant to pay $1,500 in restitution, as this amount of restitution bears a reasonable relationship to the victim’s economic loss as a result of Appellant passing the victim a bad check. Affirmed. | Welbaum | 6/20/2014 | 2014-Ohio-2669
Brock v. Food, Folks & Fun, Inc. | 25719 | The trial court did not err when it granted summary judgment to appellees. The trial court concluded that any hazard associated with the handicap accessible ramp was an open and obvious condition, thereby rendering it unforeseeable to appellees that an individual exercising ordinary care would suffer any injury when walking on or near the access ramp. The trial court further held that appellant’s admitted failure to recognize the ordinary danger associated with the handicap accessible ramp was not foreseeable by appellees. Finally, the trial court did not err when it held that the modifications and construction of the handicap accessible ramp from appellee’s original site plans constituted material deviations, thereby negating any duty appellee, Schaeffer, owed to appellant. Judgment affirmed. | Donovan | 6/20/2014 | 2014-Ohio-2668
Bass v. Bass | 25922 | Trial court acted within its discretion in concluding that Husband had failed to prove the existence of a loan from his son and in concluding that diminution in value of Wife’s IRA was due to fluctuations in the market, rather than misconduct. Trial court also reasonably awarded the marital home and a condo owned by the parties to Wife, based on its conclusion that she was more likely than Husband to be able to obtain financing which would allow her to reimburse Husband for his share of the equity. The record does not support Husband’s claim that he was required to contribute to a second mortgage taken by Wife on the marital home while the divorce was pending. Judgment affirmed. | Froelich | 6/20/2014 | 2014-Ohio-2667
State v. Thomas | 2013-CA-11 | The trial court did not err in overruling Appellant’s petition for postconviction relief given that the petition was untimely filed and otherwise lacked merit. Affirmed. | Welbaum | 6/20/2014 | 2014-Ohio-2666
State Auto. Mut., Inc. v. Brannan | 26063 | The municipal court lacked authority as a matter of law to sua sponte vacate the default judgment entered against Brannan in the absence of a motion. Judgment reversed and vacated. Remanded for further proceedings consistent with this opinion. | Donovan | 6/13/2014 | 2014-Ohio-2557
State v. Staples | 2013-CA-52 | The trial court lacked jurisdiction to rule on Appellant’s petition for postconviction relief, as the petition was untimely filed and Appellant was not unduly prevented from discovering the facts underlying the claims in his petition. Accordingly, the trial court’s denial of Appellant’s petition for postconviction relief was proper. Affirmed. | Welbaum | 6/13/2014 | 2014-Ohio-2556
State v. Jefferson | 26022 | The trial court did not err in denying defendant’s motion for resentencing based on void judgment. The trial court’s alleged failure to merge allied offenses of similar import did not render judgment of conviction void and defendant’s argument was barred by res judicata. Even if the argument were considered, the trial court did not err in failing to merge his offenses prior to accepting his guilty pleas and defendant did not establish that his offenses were allied offenses of similar import. Trial court did not err in denying defendant’s post-sentence motion to withdraw guilty plea. Trial court was not required by Crim.R. 11 to consider allied offenses of similar import when informing him of the “maximum penalty” for his offenses. Defendant did not demonstrate that a manifest injustice had occurred. Judgment affirmed. | Froelich | 6/13/2014 | 2014-Ohio-2555
State v. Gladman | 2013 CA 99 | Evidence adduced at the suppression hearing established that the deputy sheriff had a reasonable articulable basis upon which to initiate a traffic stop of the appellant and conduct field sobriety tests. The results of appellant’s breath test are not necessary or required to sustain the trial court’s finding of guilt after his no contest plea to a violation of R.C. 4511.19(A)(1)(a). Thus, any issues regarding the admissibility of the results of the breathalyzer exam administered by the deputy sheriff are moot. Judgment affirmed. | Donovan | 6/13/2014 | 2014-Ohio-2554
State v. Byrd | 25842 | Defendant’s conviction for attempted rape was not against the manifest weight of the evidence. The trial court did not commit plain error in allowing “other acts” evidence that defendant made unwanted sexual advances toward the complainant’s mother one week after the attempted rape, and defense counsel did not render ineffective assistance in failing to object to that evidence. The other acts evidence was admissible to explain how and why the teenager revealed the attempted rape. Moreover, the incident with the mother was incorporated in counsel’s defense strategy. Although the prosecutor’s isolated statement on closing was improper, it did not affect the outcome of the trial. Defendant’s five-year sentence was not contrary to law and, even if we applied an abuse of discretion standard, the sentence was not an abuse of discretion. Judgment affirmed. | Froelich | 6/13/2014 | 2014-Ohio-2553
Brumage v. Green | 2014-CA-7 | In negligence action, where injuries to the plaintiff arose from his being flipped off an all-terrain vehicle he was driving, he was engaged in a recreational activity, the primary-assumption-of-risk doctrine applies, and the trial court did not err in rendering summary judgment for the defendant. Affirmed. | Fain | 6/13/2014 | 2014-Ohio-2552
State v. Brown | 25653 | The trial court erred in failing to advise the appellant at sentencing of the length of his post-release control term. The appellant was entitled to raise the issue in a post-judgment motion because the failure to inform him of the duration of post-release control at sentencing rendered that portion of his sentence void. Trial court order affirmed in part, reversed in part, and cause remanded for a limited re-sentencing to correct the imposition of post-release control. | Wright | 6/13/2014 | 2014-Ohio-2551
State v. Taylor | 25764 | The trial court did not err in overruling the appellant’s pre-trial suppression motion. The appellant traveled from the Detroit area to a local pawn shop and back while voluntarily carrying a cell phone that emitted “pings.” He had no reasonable expectation of privacy in these pings, which were recorded by the cell phone carrier. Therefore, the Fourth Amendment did not prohibit police from tracking the location of the pings without a warrant. Judgment affirmed. | Hall | 6/13/2014 | 2014-Ohio-2550
Mann v. Resolution T Co., L.L.C. | 2014-CA-5 | The trial court did not err in rendering summary judgment on behalf of the Appellee regarding Appellants’ attempt to recover attorney fees paid to Appellee in connection with the sale of Appellants’ property in a prior foreclosure action. The foreclosure decree was a final appealable order, and issues pertaining to attorney fees should have been raised in the foreclosure action, by way of appeal or by a Civ.R. 60(B) motion for relief from judgment. Appellant’s claims in this action, therefore, are barred by res judicata. However, the trial court did err in rendering summary judgment on behalf of Appellee with respect to Appellants’ claim for slander of title. There are genuine issues of material fact concerning the slander of title claim, and whether Appellee acted in bad faith. Affirmed in part, Reversed in part, and Remanded for further proceedings. | Welbaum | 6/6/2014 | 2014-Ohio-2451
PNC Bank, N.A. v. O'Malley | 25931 | The trial court did not err in confirming the sale of mortgagors’ property following foreclosure. The plaintiff bank’s standing to bring the foreclosure action was pled in its complaint, which included allegations of two loan modification agreements entered into between the mortgagors and National City Mortgage Co., copies of which were attached to the complaint, and allegations of successions in interest from National City Mortgage Co., to National City Mortgage, Inc., to National City Real Estate Services LLC, to the plaintiff. Judgment Affirmed. (Donovan, J., concurs in judgment only.) (Hall, J., concurring.) | Fain | 6/6/2014 | 2014-Ohio-2450
Loughman v. Loughman | 25835 | The trial court did not abuse its discretion in dividing the parties’ property and debts, and it did not abuse its discretion in ordering that Appellant’s visitation with the minor children be supervised. Judgment affirmed. | Donovan | 6/6/2014 | 2014-Ohio-2449
State v. Hall | 25963, 25964 | Two consolidated appeals, one from a conviction and sentence, following a guilty plea, to Assault and Petty Theft, misdemeanors of the first degree, and one from a conviction and sentence, also following a guilty plea, to Felonious Assault (Deadly Weapon), a felony of the second degree. Defendant’s sentence for Felonious Assault was an agreed sentence of four years. His sentences for the misdemeanors were 180 days for each, to be served concurrently with one another, and concurrently with the felony sentence. Anders brief filed. No potential assignments of error having arguable merit found. Affirmed. | Fain | 6/6/2014 | 2014-Ohio-2448
Haight v. Cheap Escape Co. | 25983 | The trial court erred in concluding that the definition of “employee” set forth in R.C. 4111.14(B)(1) was not in conflict with the definition of that term contained in the Fair Labor Standards Act, 29 U.S.C. 203(e), and as incorporated into the Ohio Fair Minimum Wage Amendment, Ohio Constitution, Article II, Section 34a. The legislature was permitted to pass laws implementing Section 34a and to extend its coverage, but it was not permitted to restrict any of its provisions. Insofar as R.C. 4111.14(B)(1) impermissibly narrows the definition of “employee” set forth in Section 34a, it is invalid. Judgment reversed and remanded. (Welbaum, J., dissenting). | Froelich | 6/6/2014 | 2014-Ohio-2447
State v. Greaves | 2013-CA-91 | The trial court did not err in failing to suppress field-sobriety test results where reasonable, articulable suspicion of alcohol-related impairment existed and justified administering the tests. The tests were conducted in substantial compliance with National Highway Traffic Safety Administration (NHTSA) standards. The trial court’s ruling that precluded the defense expert witness from rendering opinion testimony as to whether the field-sobriety tests had been administered in substantial compliance with standards was not an abuse of discretion. There was no testimony offered to show that the witness had particularized training, knowledge or experience in the meaning of substantial compliance in the context of field sobriety tests. Substantial compliance with NHTSA’s requirements “is a legal standard for a court’s determination.” State v. Davis, 2d Dist. Clark No. 2008 CA 65, 2009-Ohio-3759, ¶ 18. Moreover, any error in the trial court’s failure to qualify a defense witness as an expert was harmless. The witness testified at length about NHTSA standards and his observations from the cruiser video of the tests performed. Expert testimony from the witness on the precise legal issue of substantial compliance, even if admissible, would not have impacted the trial court or our own independent review. Judgment affirmed. | Hall | 6/6/2014 | 2014-Ohio-2446
State v. Gorby | 25875 | Trial court erred in overruling motion to suppress evidence seized from person of defendant during pat-down search for weapons. Officer’s testimony that upon feeling “a lumpy cellophane bag,” she “knew it was contraband,” while sufficient to establish that she believed it to be contraband, was insufficient to establish that she had probable cause to believe it was contraband. Officer did not base her conclusion that what she felt was contraband upon her training, experience, or any other facts to support her conclusion. Reversed and Remanded. (Welbaum, J., concurring.) | Fain | 6/6/2014 | 2014-Ohio-2445
In re D.S. | 2013 CA 51 | The trial court reasonably concluded that child’s best interest was served by granting legal custody to a non-relative with whom he had lived since birth. Legal custodian provided stability and consistency that allowed the child to thrive, and Mother had not demonstrated knowledge of or a consistent ability to deal with child’s needs. Judgment affirmed. | Froelich | 6/6/2014 | 2014-Ohio-2444
State v. Collins | 25874 | Appellant’s five-year sentence for unlawful sexual conduct with a minor, a felony of the third degree, was neither contrary to law nor an abuse of discretion. Appellant’s conviction was not against the manifest weight of the evidence. Judgment affirmed. | Donovan | 6/6/2014 | 2014-Ohio-2443
State v. Brown | 26002 | Appellate counsel filed an Anders brief concluding that there are no meritorious issues to present on appeal. Neither the Appellant nor his counsel raised any potential assignments of error having arguable merit. After conducting an independent review of the proceedings, we agree that there are no meritorious issues for appeal. Affirmed. | Welbaum | 6/6/2014 | 2014-Ohio-2442
State v. Summers | 2013 CA 16 | The trial court’s imposition of a one-year sentence on one count of sexual battery, to run consecutively with a 20-year sentence imposed for similar conduct in another county, was not contrary to law or an abuse of discretion. Judgment affirmed. | Froelich | 6/6/2014 | 2014-Ohio-2441
State v. Croom | 25949 | The trial court, upon remand, failed to properly consider Appellant’s present and future ability to pay restitution, in the amount of $10,291.96, while serving a sentence of life without the possibility of parole. The imposition of restitution is reversed and vacated. Remanded for the sole purpose for the trial court to enter an order vacating restitution. (Hall, J., concurring in judgment by separate opinion.) | Donovan | 5/30/2014 | 2014-Ohio-2315
State v. Sexton | 25862 | The trial court did not violate the appellant’s right to a jury trial. The appellant failed to file a written jury demand despite having an opportunity to do so. The trial court did not abuse its discretion in denying a last-minute motion for a continuance to identify and locate an unidentified witness whose testimony was of unknown value. The record does not reflect a statutory speed-trial violation when tolling events chargeable to the appellant are taken into account. Judgment affirmed. | Hall | 5/30/2014 | 2014-Ohio-2314
State v. Riley | 2013 CA 37 | The appellant’s domestic-violence conviction is supported by legally sufficient evidence and is not against the manifest weight of the evidence. The record supports a finding that the appellant committed domestic violence by repeatedly punching his son in the face with a closed fist. Judgment affirmed. | Hall | 5/30/2014 | 2014-Ohio-2313
Maddox v. Greene Cty. Children Servs. Bd. of Dirs. | 2013-CA-38 | Defendant-appellant children-services board was sui juris for purposes of plaintiff’s complaint alleging violations of R.C. 121.22, Ohio’s open-meeting act (OMA). The record supports a finding that the children-services board committed multiple OMA violations by entering executive session without sufficiently stating a proper purpose, failing to reopen its meetings to the public after executive session, and improperly taking official action in executive session or when the public was excluded. The record also supports the trial court’s imposition of multiple statutory forfeitures and its award to plaintiff-cross appellant of attorney fees and back pay. The trial court erred, however, in finding two OMA violations that did not exist and in assessing twelve forfeitures where only seven were warranted. The trial court also erred in reducing plaintiff’s attorney-fee award by $22,232.50 where the reduction was redundant. Judgment affirmed in part, reversed in part, and cause remanded. | Hall | 5/30/2014 | 2014-Ohio-2312
State v. Lovato | 25683 | Trial court did not err in failing to merge kidnapping charges with felonious assault charges or kidnapping charges with rape charges. Counsel did not render ineffective assistance by failing to argue that the charges should be merged as allied offenses of similar import. Trial court did not err in denying motion to suppress defendant’s confession. Defendant’s challenge to his conviction for intimidating a witness, a first-degree misdemeanor, is moot. Judgment affirmed. | Froelich | 5/30/2014 | 2014-Ohio-2311
State v. Kosak | 2013 CA 67 | The trial court did not impose a sentence that was contrary to law and was not required to state its specific reasons for imposing non-minimum sentences. Defendant failed to establish that her sentence was disproportionate to unidentified co-defendants. Judgment affirmed. | Froelich | 5/30/2014 | 2014-Ohio-2310
State v. Jones | 25724 | Anders appeal. No potentially meritorious claim that defendant’s conviction for aggravated robbery was based on insufficient evidence and was against the manifest weight of the evidence. Judgment affirmed. | Froelich | 5/30/2014 | 2014-Ohio-2309
State v. Johnson | 2013-CA-85 | Defendant pled guilty to third-degree Burglary, in violation of R.C. 2911.12(A)(3), as part of plea bargain in which a count of second-degree Burglary, in violation of R.C. 2911.12(A)(2), was dismissed. Defendant had prior criminal record of ten theft-related offenses, although none of those offenses had been committed within the preceding ten years. The maximum, 36-month sentence imposed was neither clearly and convincingly contrary to the facts in the record, an abuse of discretion, nor contrary to law. Affirmed. | Fain | 5/30/2014 | 2014-Ohio-2308
State v. Jennings | 2013 CA 60 | Defendant’s guilty pleas to two drug offenses and having a weapon while under disability were not rendered involuntary by the trial court’s failure to notify him, at the plea hearing, that a post-release control violation could result in imprisonment up to nine months for each violation when the defendant was informed of the total aggregate sanction. Trial court’s imposition of consecutive sentences was not erroneous. From this record, the trial court’s sentence was not contrary to law due to the fact that the ORAS assessment considers the neighborhood in which defendant resides. Judgment affirmed. (Hall, J., concurring.) | Froelich | 5/30/2014 | 2014-Ohio-2307
Greenlee c. Greenlee | 26059 | The trial court did not abuse its discretion in refusing to modify custody. The court’s decision is supported by the evidence and is not against the manifest weight of the evidence. The court also did not err in relying on the report of the Guardian ad Litem. The matters that Appellant challenges are minor or are issues pertaining to credibility, which the trial court was in the best position to judge. Finally, allegations pertaining to Appellee’s attempts to alienate the minor child’s affections are outside the trial court record and may not be considered on appeal. Affirmed. | Welbaum | 5/30/2014 | 2014-Ohio-2306
State v. Green | 2012 CA 64 | Anders appeals. No potentially meritorious claims related to denial of motion to suppress evidence, pleas, convictions, or sentences. Judgment affirmed. | Froelich | 5/30/2014 | 2014-Ohio-2305
Folck v. Patton | 2013-CA-105 | Evidence in administrative record supports decision by the Ohio Unemployment Compensation Review Commission denying former employee’s application for compensation. Commission could reasonably find, from the evidence in its record, that the former employee was paid commissions in accordance with the commission agreement with his employer, and that employee quit without just cause. Hearing officer did not abuse her discretion by continuing with the hearing after a witness subpoenaed by the former employee declined to testify, in view of fact that former employee did not seek to enforce the subpoena by the use of contempt proceedings, and did not proffer the expected testimony of the witness. Three other applications were properly denied as being relitigation of the prior application, or untimely, respectively. Judgment of trial court affirming decision of Commission Affirmed. | Fain | 5/30/2014 | 2014-Ohio-2304
State v. Dover | 2013-CA-58 | Defendant’s conviction for Aggravated Robbery is not against the manifest weight of the evidence. Victim testified that the barrel of a small gun was pushed into her back, and that she was told to give the defendant her purse, or he would kill her. Facts that victim said during her 911 call that the gun was pointed at her head, and that other witnesses, none of whom were present at the robbery scene when the robbery was being committed, did not see a gun, were matters that the jury could consider, but did not prevent the jury from reasonably crediting the victim’s testimony. The trial court did not err in overruling the defendant’s request for a jury instruction on Theft. The State agreed that the defendant would have been entitled to a jury instruction on Robbery, which the defendant did not request, because the jury might reasonably have disbelieved the victim’s testimony that the defendant used a gun, but there is no reasonable view of the evidence that would support a conviction on the charge of Theft without also supporting a conviction for Robbery. Thus, the giving of the requested instruction on Theft would have confronted the jury with the choice of reaching an unreasonable conclusion. The trial court did not err in imposing a maximum prison sentence of eleven years for Aggravated Robbery (plus three years for a firearm specification). The defendant had a significant prior record of juvenile and adult offenses, including two prison terms, and the defendant was on bond for a municipal court case when he committed this event. Affirmed. | Fain | 5/30/2014 | 2014-Ohio-2303
Bomberger-Cronin v. Cronin | 2014-CA-4 | The trial court did not abuse its discretion in creating a shared parenting plan. The record indicates that the parties had shared parenting with equal parenting time without incident for a substantial period of time before the final divorce hearing. The shared parenting plan also was not insufficient because it omitted school placement; the child was well below school age, and this was not, therefore, a relevant factor under R.C. 3109.04(A)(2). Finally, the trial court did not err in deviating from the recommendations of the GAL. The trial court was not obligated to follow the GAL’s recommendations, and the court’s decision was not unreasonable, arbitrary, or unconscionable. Affirmed. | Welbaum | 5/30/2014 | 2014-Ohio-2302
State v. Brown | 2013-CA-13 | Trial judge who found defendant to have violated the conditions of his community control sanctions and imposed a prison sentence had earlier been the prosecutor in this case. Defendant forfeited any claim of bias and prejudice when he elected to proceed to trial before the trial judge without filing an affidavit of bias and prejudice in the Supreme Court of Ohio. Record fails to demonstrate that trial counsel was ineffective for having failed to file an affidavit of bias and prejudice. Because the four-year sentence was originally imposed, and put into execution, before the effective date of 2011 House Bill 86, the reduction of the applicable maximum sentence in that legislation to three years did not apply to this defendant. Therefore, the trial court could properly reimpose a four-year sentence (with credit for time served) after the revocation of community control sanctions, which had been imposed after the defendant’s judicial release before the expiration of his original sentence. Affirmed. | Fain | 5/30/2014 | 2014-Ohio-2301
Bank of Am., N.A. v. Thompson | 25952 | (1) The trial court had jurisdiction over this foreclosure action. Appellee was the holder of the note and mortgage when it initiated the action, so it had standing. (2) Summary judgment is appropriate because Appellee presented the required evidence and no genuine issue of material fact remains. (3) Appellant received due process. She was given reasonable notice of judicial process and was given a reasonable opportunity to be heard. (4) Appellee did not fail to properly identify its relationship to the note and violate Civ.R. 8(E). In its complaint, Appellee correctly identified itself as the holder of the note and mortgage. Judgment affirmed. (Froelich, P.J., concurring.) (Donovan, J., concurs in judgment only.) | Hall | 5/30/2014 | 2014-Ohio-2300
State v. Snowden | 25758 | The trial court did not abuse its discretion in excusing a prospective juror for cause on the State’s motion, since the prospective juror was unsuitable to serve as a juror based upon his expression of doubt that he could reach a decision, his statement that he would “probably” follow the law if instructed on aiding and abetting, and his acknowledgment of potential bias toward the State’s witnesses who were associated with a crack house. At sentencing the trial court failed to make the findings required by R.C. 2929.14(C) for consecutive sentences. The judgment of the trial court is affirmed in part and reversed in part, and the matter is remanded to the trial court for the sole purpose of giving the trial court the opportunity to consider the requisite findings for imposing consecutive sentences under R.C. 2929.14(C). | Donovan | 5/30/2014 | 2014-Ohio-2299

Page: [ 1] 2 3 4 next